[![ci](https://github.com/mjx-project/mjx/actions/workflows/ci.yml/badge.svg)](https://github.com/mjx-project/mjx/actions/workflows/ci.yml)

# Mjx

## Requirements

- `Ubuntu 20.04` or later
- `MacOS 10.15` or later <!-- <filesystem> requires macos-10.15 -->
- `Python >= 3.7` <!-- importlib requires 3.7 -->

## Visualization

Available at https://mjx-visualizer.an.r.appspot.com/
